#!/bin/sh
export PATH='/usr/obj/ports/hs-largeword-1.0.5/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: largeword
version: 1.0.5
id: largeword-1.0.5-f6c1675c52751d1ad2c5801b91b76fd7

license: BSD3
copyright: Dominic Steinitz <dominic@steinitz.org>
maintainer: Dominic Steinitz <dominic@steinitz.org>
stability: stable
homepage: https://github.com/idontgetoutmuch/largeword
package-url:
synopsis: Provides Word128, Word192 and Word256 and a way of producing other large words if required.
description: Provides Word128, Word192 and Word256 and a way of producing other large words if required.
category: Data
author: Dominic Steinitz <dominic@steinitz.org>
pkgpath: devel/hs-largeword
exposed: True
exposed-modules: Data.LargeWord
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/largeword-1.0.5
library-dirs: /usr/local/lib/ghc/largeword-1.0.5
hs-libraries: HSlargeword-1.0.5
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.7.0.2-b11c3b9ddc2bebe1a3d85499c9ea3f18
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-largeword-1.0.5/html/largeword.haddock
haddock-html: /usr/local/share/doc/hs-largeword-1.0.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
